@@ -8,6 +8,7 @@ from gradio.inputs import InputComponent
 from gradio.outputs import OutputComponent
 from gradio import networking, strings, utils
 from gradio.interpretation import quantify_difference_in_label
+from gradio import encryptor
 import pkg_resources
 import requests
 import random
@@ -22,6 +23,7 @@ import os
 import copy
 import markdown2
 import json
+from getpass import getpass
 
 analytics.write_key = "uxIFddIEuuUcFLf9VgH2teTEtPlWdkNy"
 analytics_url = 'https://api.gradio.app/'
@@ -49,7 +51,7 @@ class Interface:
                  capture_session=False, interpretation=None,
                  title=None, description=None, article=None, thumbnail=None, 
                  css=None, server_port=7860, server_name=networking.LOCALHOST_NAME,
-                 allow_screenshot=True, allow_flagging=True, flagging_options=None,
+                 allow_screenshot=True, allow_flagging=True, flagging_options=None, encrypt=False,
                  show_tips=True, embedding=None, flagging_dir="flagged", analytics_enabled=True):
 
         """
@@ -58,7 +60,7 @@ class Interface:
         inputs (Union[str, List[Union[str, InputComponent]]]): a single Gradio input component, or list of Gradio input components. Components can either be passed as instantiated objects, or referred to by their string shortcuts. The number of input components should match the number of parameters in fn.
         outputs (Union[str, List[Union[str, OutputComponent]]]): a single Gradio output component, or list of Gradio output components. Components can either be passed as instantiated objects, or referred to by their string shortcuts. The number of output components should match the number of values returned by fn.
         verbose (bool): whether to print detailed information during launch.
-        examples (List[List[Any]]): sample inputs for the function; if provided, appears below the UI components and can be used to populate the interface. Should be nested list, in which the outer list consists of samples and each inner list consists of an input corresponding to each input component.
+        examples (Union[List[List[Any]], str]): sample inputs for the function; if provided, appears below the UI components and can be used to populate the interface. Should be nested list, in which the outer list consists of samples and each inner list consists of an input corresponding to each input component. A string path to a directory of examples can also be provided. If there are multiple input components, a log.csv file must be present in the directory to link corresponding inputs.
         examples_per_page (int): If examples are provided, how many to display per page.
         live (bool): whether the interface should automatically reload on change.
         layout (str): Layout of input and output panels. "horizontal" arranges them as two columns of equal height, "unaligned" arranges them as two columns of unequal height, and "vertical" arranges them vertically.
@@ -74,6 +76,7 @@ class Interface:
         allow_screenshot (bool): if False, users will not see a button to take a screenshot of the interface.
         allow_flagging (bool): if False, users will not see a button to flag an input and output.
         flagging_options (List[str]): if not None, provides options a user must select when flagging.
+        encrypt (bool): If True, flagged data will be encrypted by key provided by creator at launch
         flagging_dir (str): what to name the dir where flagged data is stored.
         show_tips (bool): if True, will occasionally show tips about new Gradio features
         """
@@ -148,10 +151,13 @@ class Interface:
         self.allow_flagging = os.getenv("GRADIO_FLAGGING") or allow_flagging
         self.flagging_options = flagging_options 
         self.flagging_dir = flagging_dir
+        self.encrypt = encrypt
         Interface.instances.add(self)
         self.analytics_enabled=analytics_enabled
         self.save_to = None
         self.share = None
+        self.share_url = None
+        self.local_url = None
         self.embedding = embedding
         self.show_tips = show_tips
 
@@ -367,14 +373,15 @@ class Interface:
                 print("PASSED")
                 continue
 
-    def launch(self, inline=None, inbrowser=None, share=False, debug=False, auth=None):
+    def launch(self, inline=None, inbrowser=None, share=False, debug=False, auth=None, auth_message=None, private_endpoint=None):
         """
         Parameters:
         inline (bool): whether to display in the interface inline on python notebooks.
         inbrowser (bool): whether to automatically launch the interface in a new tab on the default browser.
         share (bool): whether to create a publicly shareable link from your computer for the interface.
         debug (bool): if True, and the interface was launched from Google Colab, prints the errors in the cell output.
-        auth (Tuple[str, str]): If provided, username and password required to access interface.
+        auth (Union[Tuple[str, str], List[Tuple[str, str]]]): If provided, username and password (or list of username-password tuples) required to access interface.
+        auth_message (str): If provided, HTML message provided on login page.
         Returns:
         app (flask.Flask): Flask app object
         path_to_local_server (str): Locally accessible link
@@ -386,12 +393,20 @@ class Interface:
         # Set up local flask server
         config = self.get_config_file()
         self.config = config
+        if auth and not isinstance(auth[0], tuple) and not isinstance(auth[0], list):
+            auth = [auth]
         self.auth = auth
+        self.auth_message = auth_message
+
+        # Request key for encryption
+        if self.encrypt:
+            self.encryption_key = encryptor.get_key(getpass("Enter key for encryption: "))
 
         # Launch local flask server
         server_port, app, thread = networking.start_server(
             self, self.server_name, self.server_port, self.auth)
         path_to_local_server = "http://{}:{}/".format(self.server_name, server_port)
+        self.local_url = path_to_local_server
         self.server_port = server_port
         self.status = "RUNNING"
         self.server = app
@@ -411,12 +426,17 @@ class Interface:
         else:
             print(strings.en["RUNNING_LOCALLY"].format(path_to_local_server))
 
+        if private_endpoint is not None:
+            share = True
         # Set up shareable link 
         self.share = share
+
         if share:
-            print(strings.en["SHARE_LINK_MESSAGE"])
+            if not private_endpoint:
+                print(strings.en["SHARE_LINK_MESSAGE"])
             try:
-                share_url = networking.setup_tunnel(server_port)
+                share_url = networking.setup_tunnel(server_port, private_endpoint)
+                self.share_url = share_url
                 print(strings.en["SHARE_LINK_DISPLAY"].format(share_url))
             except RuntimeError:
                 send_error_analytics(self.analytics_enabled)
@@ -462,6 +482,15 @@ class Interface:
         
         return app, path_to_local_server, share_url
 
+
+    def integrate(self, comet_ml=None):
+        if self.share_url is not None:
+            comet_ml.log_text(self.share_url)
+            comet_ml.end()
+        else:
+            comet_ml.log_text(self.local_url)
+            comet_ml.end()
+
 def show_tip(io):
     if not(io.show_tips):
         return
