@@ -5,6 +5,7 @@ from IPython import get_ipython
 analytics_url = 'https://api.gradio.app/'
 PKG_VERSION_URL = "https://api.gradio.app/pkg-version"
 
+
 def version_check():
     try:
         current_pkg_version = pkg_resources.require("gradio")[0].version
@@ -18,6 +19,7 @@ def version_check():
     except:  # TODO(abidlabs): don't catch all exceptions
         pass
 
+
 def error_analytics(type):
     """
     Send error analytics if there is network
@@ -26,8 +28,8 @@ def error_analytics(type):
     data = {'error': '{} in launch method'.format(type)}
     try:
         requests.post(analytics_url + 'gradio-error-analytics/',
-                      data=data)
-    except requests.ConnectionError:
+                      data=data, timeout=3)
+    except (requests.ConnectionError, requests.exceptions.ReadTimeout):
         pass  # do not push analytics if no network
 
 
@@ -56,4 +58,14 @@ def ipython_check():
         is_ipython = True
     except NameError:
         is_ipython = False
-    return is_ipython
\ No newline at end of file
+    return is_ipython
+
+
+def readme_to_html(article):
+    try:
+        response = requests.get(article, timeout=3)
+        if response.status_code == requests.codes.ok:
+            article = response.text
+    except requests.exceptions.RequestException:
+        pass
+    return article
